/*
 * Reference documents
 * - http://www.si-linux.co.jp/techinfo/index.php?BeagleBoneBlackBox_USB%E9%9B%BB%E6%BA%90%E5%88%B6%E5%BE%A1
 * - http://www.dreamincode.net/forums/topic/148707-introduction-to-using-libusb-10/
 */

#include <stdio.h>
#include <libusb-1.0/libusb.h>

#define VENDOR_ID  0x1d6b
#define CTRL_TIMEOUT 1000 

void reset_dev(libusb_device *dev) {
	int r;
	uint8_t request;
	libusb_device_handle *dh;
	struct libusb_device_descriptor desc = {0};

	r = libusb_get_device_descriptor(dev, &desc);
	if (r < 0) {
		printf("ERROR: Fail to get device descriptor\n");
		return;
	}

	if (desc.idVendor == VENDOR_ID) {
		libusb_open(dev, &dh);
		libusb_reset_device(dh);
		libusb_close(dh);
	}
	return;
}

int main(int argc, char* argv[])
{
	libusb_device **devs;
	libusb_context *ctx = NULL;
	int r;
	int i;
	int cnt;

	r = libusb_init(&ctx);

	if (r < 0) {
		printf("ERROR libusb init %d\n",r);
		return 1;
	}

	cnt = libusb_get_device_list(ctx, &devs);
	if(cnt < 0) {
		printf("ERROR get device in list %d\n",cnt);	
	}

	for (i=0; i<cnt; i++) {
		reset_dev(devs[i]);
	}
	
	libusb_free_device_list(devs,1);
	libusb_exit(ctx);

	return 0;
}
